/**
 * © 2024 aiyoudiao
 *
 * This file was created by aiyoudiao, containing a lot of hard work and wisdom.
 *
 * You are free to use, modify, and distribute this file, but please keep this copyright notice.
 *
 * If you find this file helpful, please give me a star or follow me ツ.
 *
 * Contact:
 * - Email: newdiao@163.com
 * - GitHub: https://github.com/aiyoudiao
 *
 * Happy coding! Remember, code is poetry, and front-end is art. ツ
 */
/** Key-value mapping of HTTP status codes and HTTP status texts. */
export declare const statusCodeToStatusTextMap: Record<number, string>;
/** Key-value mapping of HTTP status codes and HTTP status descriptions. */
export declare const statusCodeToStatusDescriptionMap: Record<number, string>;
/** Key-value mapping of HTTP status texts and HTTP status codes. */
export declare const statusTextToStatusCodeMap: Record<string, number>;
/** Key-value mapping of HTTP status texts and HTTP status descriptions. */
export declare const statusTextToStatusDescriptionMap: Record<string, string>;
export type HTTPStatusCode = keyof typeof statusCodeToStatusTextMap;
export type HTTPStatusText = keyof typeof statusTextToStatusCodeMap;
export type StatusInfo = {
    code: number;
    message: string;
    success: boolean;
};
/**
 * Returns whether the provided status code or status text is valid or not.
 * @example isCodeOrTextValid(200) -> true
 * isCodeOrTextValid('OK') -> true
 *
 * @param codeOrText: HTTPStatusCode | HTTPStatusText
 * @returns yesOrNo: boolean
 */
export declare function isCodeOrTextValid(codeOrText: HTTPStatusCode | HTTPStatusText): boolean;
/**
 * Returns an object containing information about the provided status code or status text.
 * @example getStatusInfo(200) -> { code: 200, message: 'OK：The standard response for successful HTTP requests.', success: true}
 * getStatusInfo('OK') -> { code: 200, message: 'OK：The standard response for successful HTTP requests.', success: true}
 *
 * @param codeOrText: HTTPStatusCode | HTTPStatusText
 * @returns StatusInfo: { code: number, message: string, success: boolean}
 */
export declare function getStatusInfo(codeOrText: HTTPStatusCode | HTTPStatusText): StatusInfo;
/**
 * Returns whether the provided status code or status text is a successful status or not.
 * @example isStatusSuccessful(200) -> true
 * isStatusSuccessful('OK') -> true
 * isStatusSuccessful(400) -> false
 * isStatusSuccessful('Bad request') -> false
 *
 * @param codeOrText: HTTPStatusCode | HTTPStatusText
 * @returns successful: boolean
 */
export declare function isStatusSuccessful(codeOrText: HTTPStatusCode | HTTPStatusText): boolean;
/**
 * Returns a string containing the provided status code and simple message.
 * @example getSimpleStatusMessage(200) -> 200 OK
 * getSimpleStatusMessage('OK') -> 200 OK
 *
 * @param codeOrText: HTTPStatusCode | HTTPStatusText
 * @returns simpleStatusMessage: string
 */
export declare function getSimpleStatusMessage(codeOrText: HTTPStatusCode | HTTPStatusText): string;
/**
 * Returns a string containing the provided status code and message.
 * @example getStatusMessage(200) -> 200 OK：The standard response for successful HTTP requests.
 * getStatusMessage('OK') -> 200 OK：The standard response for successful HTTP requests.
 *
 * @param codeOrText: HTTPStatusCode | HTTPStatusText
 * @returns statusMessage: string
 */
export declare function getStatusMessage(codeOrText: HTTPStatusCode | HTTPStatusText): string;
/**
 * Returns the status code for the given http status text.
 * If the given http status text does not exist, undefined is returned.
 * @example getStatusCode('OK') -> 200
 * @param text: HTTPStatusText
 * @returns statusCode: HTTPStatusCode
 */
export declare function getStatusCode(text: HTTPStatusText): HTTPStatusCode;
/**
 * Returns the status text for the given http status code.
 * If the given http status code does not exist, undefined is returned.
 * @example getStatusCode('200') -> OK
 * @param code: HTTPStatusCode
 * @returns statusText: HTTPStatusText
 */
export declare function getStatusText(code: HTTPStatusCode): HTTPStatusText;
